@@ -7,6 +7,10 @@
 
 #define PLUGIN_WINDOWS_NAME "windows.plugin"
 
+// https://learn.microsoft.com/es-es/windows/win32/sysinfo/kernel-objects?redirectedfrom=MSDN
+// 2^24
+#define WINDOWS_MAX_KERNEL_OBJECT 16777216
+
 void *win_plugin_main(void *ptr);
 
 extern char windows_shared_buffer[8192];
@@ -19,6 +23,7 @@ int do_PerflibNetwork(int update_every, usec_t dt);
 int do_PerflibProcesses(int update_every, usec_t dt);
 int do_PerflibProcessor(int update_every, usec_t dt);
 int do_PerflibMemory(int update_every, usec_t dt);
+int do_PerflibObjects(int update_every, usec_t dt);
 
 #include "perflib.h"
 
