@@ -7,6 +7,10 @@
 
 #include "database/engine/page_test.h"
 
+#ifdef OS_WINDOWS
+#include "win_system-info.h"
+#endif
+
 #ifdef ENABLE_SENTRY
 #include "sentry-native/sentry-native.h"
 #endif
@@ -16,14 +20,12 @@
 #endif
 
 bool unittest_running = false;
-int netdata_zero_metrics_enabled;
 int netdata_anonymous_statistics_enabled;
 
 int libuv_worker_threads = MIN_LIBUV_WORKER_THREADS;
 bool ieee754_doubles = false;
 time_t netdata_start_time = 0;
 struct netdata_static_thread *static_threads;
-bool i_am_the_spawn_server = false;
 
 struct config netdata_config = {
         .first_section = NULL,
@@ -42,12 +44,12 @@ typedef struct service_thread {
     pid_t tid;
     SERVICE_THREAD_TYPE type;
     SERVICE_TYPE services;
-    char name[NETDATA_THREAD_NAME_MAX + 1];
+    char name[ND_THREAD_TAG_MAX + 1];
     bool stop_immediately;
     bool cancelled;
 
     union {
-        netdata_thread_t netdata_thread;
+        ND_THREAD *netdata_thread;
         uv_thread_t uv_thread;
     };
 
@@ -65,7 +67,7 @@ struct service_globals {
 
 SERVICE_THREAD *service_register(SERVICE_THREAD_TYPE thread_type, request_quit_t request_quit_callback, force_quit_t force_quit_callback, void *data, bool update __maybe_unused) {
     SERVICE_THREAD *sth = NULL;
-    pid_t tid = gettid();
+    pid_t tid = gettid_cached();
 
     spinlock_lock(&service_globals.lock);
     Pvoid_t *PValue = JudyLIns(&service_globals.pid_judy, tid, PJE0);
@@ -76,13 +78,12 @@ SERVICE_THREAD *service_register(SERVICE_THREAD_TYPE thread_type, request_quit_t
         sth->request_quit_callback = request_quit_callback;
         sth->force_quit_callback = force_quit_callback;
         sth->data = data;
-        os_thread_get_current_name_np(sth->name);
         *PValue = sth;
 
         switch(thread_type) {
             default:
             case SERVICE_THREAD_TYPE_NETDATA:
-                sth->netdata_thread = netdata_thread_self();
+                sth->netdata_thread = nd_thread_self();
                 break;
 
             case SERVICE_THREAD_TYPE_EVENT_LOOP:
@@ -90,6 +91,10 @@ SERVICE_THREAD *service_register(SERVICE_THREAD_TYPE thread_type, request_quit_t
                 sth->uv_thread = uv_thread_self();
                 break;
         }
+
+        const char *name = nd_thread_tag();
+        if(!name) name = "";
+        strncpyz(sth->name, name, sizeof(sth->name) - 1);
     }
     else {
         sth = *PValue;
@@ -100,7 +105,7 @@ SERVICE_THREAD *service_register(SERVICE_THREAD_TYPE thread_type, request_quit_t
 }
 
 void service_exits(void) {
-    pid_t tid = gettid();
+    pid_t tid = gettid_cached();
 
     spinlock_lock(&service_globals.lock);
     Pvoid_t *PValue = JudyLGet(service_globals.pid_judy, tid, PJE0);
@@ -119,7 +124,11 @@ bool service_running(SERVICE_TYPE service) {
 
     sth->services |= service;
 
-    return !(sth->stop_immediately || netdata_exit);
+	bool cancelled = false;
+	if (sth->type == SERVICE_THREAD_TYPE_NETDATA)
+		cancelled = nd_thread_signaled_to_cancel();
+
+    return !sth->stop_immediately && !netdata_exit && !cancelled;
 }
 
 void service_signal_exit(SERVICE_TYPE service) {
@@ -134,6 +143,17 @@ void service_signal_exit(SERVICE_TYPE service) {
         if((sth->services & service)) {
             sth->stop_immediately = true;
 
+			switch(sth->type) {
+               default:
+               case SERVICE_THREAD_TYPE_NETDATA:
+                  nd_thread_signal_cancel(sth->netdata_thread);
+                  break;
+
+               case SERVICE_THREAD_TYPE_EVENT_LOOP:
+               case SERVICE_THREAD_TYPE_LIBUV:
+                  break;
+            }
+
             if(sth->request_quit_callback) {
                 spinlock_unlock(&service_globals.lock);
                 sth->request_quit_callback(sth->data);
@@ -196,13 +216,13 @@ static bool service_wait_exit(SERVICE_TYPE service, usec_t timeout_ut) {
         bool first = true;
         while((PValue = JudyLFirstThenNext(service_globals.pid_judy, &tid, &first))) {
             SERVICE_THREAD *sth = *PValue;
-            if(sth->services & service && sth->tid != gettid() && !sth->cancelled) {
+            if(sth->services & service && sth->tid != gettid_cached() && !sth->cancelled) {
                 sth->cancelled = true;
 
                 switch(sth->type) {
                     default:
                     case SERVICE_THREAD_TYPE_NETDATA:
-                        netdata_thread_cancel(sth->netdata_thread);
+                        nd_thread_signal_cancel(sth->netdata_thread);
                         break;
 
                     case SERVICE_THREAD_TYPE_EVENT_LOOP:
@@ -253,7 +273,7 @@ static bool service_wait_exit(SERVICE_TYPE service, usec_t timeout_ut) {
         bool first = true;
         while((PValue = JudyLFirstThenNext(service_globals.pid_judy, &tid, &first))) {
             SERVICE_THREAD *sth = *PValue;
-            if(sth->services & service && sth->tid != gettid()) {
+            if(sth->services & service && sth->tid != gettid_cached()) {
                 if(running)
                     buffer_strcat(thread_list, ", ");
 
@@ -304,8 +324,7 @@ static bool service_wait_exit(SERVICE_TYPE service, usec_t timeout_ut) {
 void web_client_cache_destroy(void);
 
 void netdata_cleanup_and_exit(int ret, const char *action, const char *action_result, const char *action_data) {
-    if (i_am_the_spawn_server)
-        exit(ret);
+    netdata_exit = 1;
 
     watcher_shutdown_begin();
 
@@ -327,6 +346,9 @@ void netdata_cleanup_and_exit(int ret, const char *action, const char *action_re
     (void) rename(agent_crash_file, agent_incomplete_shutdown_file);
     watcher_step_complete(WATCHER_STEP_ID_CREATE_SHUTDOWN_FILE);
 
+    netdata_main_spawn_server_cleanup();
+    watcher_step_complete(WATCHER_STEP_ID_DESTROY_MAIN_SPAWN_SERVER);
+
 #ifdef ENABLE_DBENGINE
     if(dbengine_enabled) {
         for (size_t tier = 0; tier < storage_tiers; tier++)
@@ -471,15 +493,19 @@ void netdata_cleanup_and_exit(int ret, const char *action, const char *action_re
 
     (void) unlink(agent_incomplete_shutdown_file);
     watcher_step_complete(WATCHER_STEP_ID_REMOVE_INCOMPLETE_SHUTDOWN_FILE);
-    
+
     watcher_shutdown_end();
     watcher_thread_stop();
 
+#ifdef OS_WINDOWS
+    return;
+#endif
+
 #ifdef ENABLE_SENTRY
     if (ret)
         abort();
     else {
-        sentry_native_fini();
+        nd_sentry_fini();
         exit(ret);
     }
 #else
@@ -596,39 +622,6 @@ void web_server_config_options(void)
     }
 }
 
-
-// killpid kills pid with SIGTERM.
-int killpid(pid_t pid) {
-    int ret;
-    netdata_log_debug(D_EXIT, "Request to kill pid %d", pid);
-
-    int signal = SIGTERM;
-//#ifdef NETDATA_INTERNAL_CHECKS
-//    if(service_running(SERVICE_COLLECTORS))
-//        signal = SIGABRT;
-//#endif
-
-    errno = 0;
-    ret = kill(pid, signal);
-    if (ret == -1) {
-        switch(errno) {
-            case ESRCH:
-                // We wanted the process to exit so just let the caller handle.
-                return ret;
-
-            case EPERM:
-                netdata_log_error("Cannot kill pid %d, but I do not have enough permissions.", pid);
-                break;
-
-            default:
-                netdata_log_error("Cannot kill pid %d, but I received an error.", pid);
-                break;
-        }
-    }
-
-    return ret;
-}
-
 static void set_nofile_limit(struct rlimit *rl) {
     // get the num files allowed
     if(getrlimit(RLIMIT_NOFILE, rl) != 0) {
@@ -667,7 +660,7 @@ void cancel_main_threads() {
         if (static_threads[i].enabled == NETDATA_MAIN_THREAD_RUNNING) {
             if (static_threads[i].thread) {
                 netdata_log_info("EXIT: Stopping main thread: %s", static_threads[i].name);
-                netdata_thread_cancel(*static_threads[i].thread);
+                nd_thread_signal_cancel(static_threads[i].thread);
             } else {
                 netdata_log_info("EXIT: No thread running (marking as EXITED): %s", static_threads[i].name);
                 static_threads[i].enabled = NETDATA_MAIN_THREAD_EXITED;
@@ -676,8 +669,6 @@ void cancel_main_threads() {
         }
     }
 
-    netdata_exit = 1;
-
     while(found && max > 0) {
         max -= step;
         netdata_log_info("Waiting %d threads to finish...", found);
@@ -688,7 +679,7 @@ void cancel_main_threads() {
                 continue;
 
             // Don't wait ourselves.
-            if (static_threads[i].thread && (*static_threads[i].thread == pthread_self()))
+            if (nd_thread_is_me(static_threads[i].thread))
                 continue;
 
             found++;
@@ -704,9 +695,6 @@ void cancel_main_threads() {
     else
         netdata_log_info("All threads finished.");
 
-    for (i = 0; static_threads[i].name != NULL ; i++)
-        freez(static_threads[i].thread);
-
     freez(static_threads);
     static_threads = NULL;
 }
@@ -821,6 +809,10 @@ int help(int exitcode) {
             "                           Check if string matches pattern and exit.\n\n"
             "  -W \"claim -token=TOKEN -rooms=ROOM1,ROOM2\"\n"
             "                           Claim the agent to the workspace rooms pointed to by TOKEN and ROOM*.\n\n"
+#ifdef OS_WINDOWS
+            "  -W perflibdump [key]\n"
+            "                           Dump the Windows Performance Counters Registry in JSON.\n\n"
+#endif
     );
 
     fprintf(stream, "\n Signals netdata handles:\n\n"
@@ -1037,6 +1029,24 @@ static void backwards_compatible_config() {
     config_move(CONFIG_SECTION_GLOBAL,  "dbengine multihost disk space",
                 CONFIG_SECTION_DB,      "dbengine multihost disk space MB");
 
+    config_move(CONFIG_SECTION_DB,      "dbengine disk space MB",
+                CONFIG_SECTION_DB,      "dbengine multihost disk space MB");
+
+    config_move(CONFIG_SECTION_DB,      "dbengine multihost disk space MB",
+                CONFIG_SECTION_DB,      "dbengine tier 0 disk space MB");
+
+    config_move(CONFIG_SECTION_DB,      "dbengine tier 1 multihost disk space MB",
+                CONFIG_SECTION_DB,      "dbengine tier 1 disk space MB");
+
+    config_move(CONFIG_SECTION_DB,      "dbengine tier 2 multihost disk space MB",
+                CONFIG_SECTION_DB,      "dbengine tier 2 disk space MB");
+
+    config_move(CONFIG_SECTION_DB,      "dbengine tier 3 multihost disk space MB",
+                CONFIG_SECTION_DB,      "dbengine tier 3 disk space MB");
+
+    config_move(CONFIG_SECTION_DB,      "dbengine tier 4 multihost disk space MB",
+                CONFIG_SECTION_DB,      "dbengine tier 4 disk space MB");
+
     config_move(CONFIG_SECTION_GLOBAL,  "memory deduplication (ksm)",
                 CONFIG_SECTION_DB,      "memory deduplication (ksm)");
 
@@ -1093,7 +1103,16 @@ static int get_hostname(char *buf, size_t buf_size) {
     return gethostname(buf, buf_size);
 }
 
-static void get_netdata_configured_variables() {
+static void get_netdata_configured_variables()
+{
+#ifdef ENABLE_DBENGINE
+    legacy_multihost_db_space = config_exists(CONFIG_SECTION_DB, "dbengine multihost disk space MB");
+    if (!legacy_multihost_db_space)
+        legacy_multihost_db_space = config_exists(CONFIG_SECTION_GLOBAL, "dbengine multihost disk space");
+    if (!legacy_multihost_db_space)
+        legacy_multihost_db_space = config_exists(CONFIG_SECTION_GLOBAL, "dbengine disk space");
+#endif
+
     backwards_compatible_config();
 
     // ------------------------------------------------------------------------
@@ -1195,20 +1214,23 @@ static void get_netdata_configured_variables() {
 
     // ------------------------------------------------------------------------
     // get default Database Engine disk space quota in MiB
+//
+//    //    if (!config_exists(CONFIG_SECTION_DB, "dbengine disk space MB") && !config_exists(CONFIG_SECTION_DB, "dbengine multihost disk space MB"))
+//
+//    default_rrdeng_disk_quota_mb = (int) config_get_number(CONFIG_SECTION_DB, "dbengine disk space MB", default_rrdeng_disk_quota_mb);
+//    if(default_rrdeng_disk_quota_mb < RRDENG_MIN_DISK_SPACE_MB) {
+//        netdata_log_error("Invalid dbengine disk space %d given. Defaulting to %d.", default_rrdeng_disk_quota_mb, RRDENG_MIN_DISK_SPACE_MB);
+//        default_rrdeng_disk_quota_mb = RRDENG_MIN_DISK_SPACE_MB;
+//        config_set_number(CONFIG_SECTION_DB, "dbengine disk space MB", default_rrdeng_disk_quota_mb);
+//    }
+//
+//    default_multidb_disk_quota_mb = (int) config_get_number(CONFIG_SECTION_DB, "dbengine multihost disk space MB", compute_multidb_diskspace());
+//    if(default_multidb_disk_quota_mb < RRDENG_MIN_DISK_SPACE_MB) {
+//        netdata_log_error("Invalid multidb disk space %d given. Defaulting to %d.", default_multidb_disk_quota_mb, default_rrdeng_disk_quota_mb);
+//        default_multidb_disk_quota_mb = default_rrdeng_disk_quota_mb;
+//        config_set_number(CONFIG_SECTION_DB, "dbengine multihost disk space MB", default_multidb_disk_quota_mb);
+//    }
 
-    default_rrdeng_disk_quota_mb = (int) config_get_number(CONFIG_SECTION_DB, "dbengine disk space MB", default_rrdeng_disk_quota_mb);
-    if(default_rrdeng_disk_quota_mb < RRDENG_MIN_DISK_SPACE_MB) {
-        netdata_log_error("Invalid dbengine disk space %d given. Defaulting to %d.", default_rrdeng_disk_quota_mb, RRDENG_MIN_DISK_SPACE_MB);
-        default_rrdeng_disk_quota_mb = RRDENG_MIN_DISK_SPACE_MB;
-        config_set_number(CONFIG_SECTION_DB, "dbengine disk space MB", default_rrdeng_disk_quota_mb);
-    }
-
-    default_multidb_disk_quota_mb = (int) config_get_number(CONFIG_SECTION_DB, "dbengine multihost disk space MB", compute_multidb_diskspace());
-    if(default_multidb_disk_quota_mb < RRDENG_MIN_DISK_SPACE_MB) {
-        netdata_log_error("Invalid multidb disk space %d given. Defaulting to %d.", default_multidb_disk_quota_mb, default_rrdeng_disk_quota_mb);
-        default_multidb_disk_quota_mb = default_rrdeng_disk_quota_mb;
-        config_set_number(CONFIG_SECTION_DB, "dbengine multihost disk space MB", default_multidb_disk_quota_mb);
-    }
 #else
     if (default_rrd_memory_mode == RRD_MEMORY_MODE_DBENGINE) {
        error_report("RRD_MEMORY_MODE_DBENGINE is not supported in this platform. The agent will use db mode 'save' instead.");
@@ -1254,9 +1276,9 @@ static void get_netdata_configured_variables() {
     // --------------------------------------------------------------------
     // get various system parameters
 
-    get_system_HZ();
-    get_system_cpus_uncached();
-    get_system_pid_max();
+    os_get_system_HZ();
+    os_get_system_cpus_uncached();
+    os_get_system_pid_max();
 
 
 }
@@ -1277,7 +1299,7 @@ static void post_conf_load(char **user)
 }
 
 static bool load_netdata_conf(char *filename, char overwrite_used, char **user) {
-    errno = 0;
+    errno_clear();
 
     int ret = 0;
 
@@ -1314,6 +1336,7 @@ static inline void coverity_remove_taint(char *s)
 }
 
 int get_system_info(struct rrdhost_system_info *system_info) {
+#if !defined(OS_WINDOWS)
     char *script;
     script = mallocz(sizeof(char) * (strlen(netdata_configured_primary_plugins_dir) + strlen("system-info.sh") + 2));
     sprintf(script, "%s/%s", netdata_configured_primary_plugins_dir, "system-info.sh");
@@ -1323,15 +1346,12 @@ int get_system_info(struct rrdhost_system_info *system_info) {
         return 1;
     }
 
-    pid_t command_pid;
-
-    FILE *fp_child_input;
-    FILE *fp_child_output = netdata_popen(script, &command_pid, &fp_child_input);
-    if(fp_child_output) {
+    POPEN_INSTANCE *instance = spawn_popen_run(script);
+    if(instance) {
         char line[200 + 1];
         // Removed the double strlens, if the Coverity tainted string warning reappears I'll revert.
         // One time init code, but I'm curious about the warning...
-        while (fgets(line, 200, fp_child_output) != NULL) {
+        while (fgets(line, 200, instance->child_stdout_fp) != NULL) {
             char *value=line;
             while (*value && *value != '=') value++;
             if (*value=='=') {
@@ -1350,9 +1370,12 @@ int get_system_info(struct rrdhost_system_info *system_info) {
                 }
             }
         }
-        netdata_pclose(fp_child_input, fp_child_output, command_pid);
+        spawn_popen_wait(instance);
     }
     freez(script);
+#else
+    netdata_windows_get_system_info(system_info);
+#endif
     return 0;
 }
 
@@ -1383,6 +1406,10 @@ int uuid_unittest(void);
 int progress_unittest(void);
 int dyncfg_unittest(void);
 
+#ifdef OS_WINDOWS
+int windows_perflib_dump(const char *key);
+#endif
+
 int unittest_prepare_rrd(char **user) {
     post_conf_load(user);
     get_netdata_configured_variables();
@@ -1400,35 +1427,34 @@ int unittest_prepare_rrd(char **user) {
     return 0;
 }
 
-int main(int argc, char **argv) {
-    // initialize the system clocks
+int netdata_main(int argc, char **argv) {
     clocks_init();
-    netdata_start_time = now_realtime_sec();
+    string_init();
+    analytics_init();
 
+    netdata_start_time = now_realtime_sec();
     usec_t started_ut = now_monotonic_usec();
     usec_t last_ut = started_ut;
     const char *prev_msg = NULL;
 
     int i;
     int config_loaded = 0;
-    int dont_fork = 0;
     bool close_open_fds = true;
     size_t default_stacksize;
     char *user = NULL;
 
+#ifdef OS_WINDOWS
+    int dont_fork = 1;
+#else
+    int dont_fork = 0;
+#endif
+
     static_threads = static_threads_get();
 
     netdata_ready = false;
     // set the name for logging
     program_name = "netdata";
 
-    if (argc > 1 && strcmp(argv[1], SPAWN_SERVER_COMMAND_LINE_ARGUMENT) == 0) {
-        // don't run netdata, this is the spawn server
-        i_am_the_spawn_server = true;
-        spawn_server();
-        exit(0);
-    }
-
     // parse options
     {
         int num_opts = sizeof(option_definitions) / sizeof(struct option_def);
@@ -1490,7 +1516,7 @@ int main(int argc, char **argv) {
                     break;
                 case 'v':
                 case 'V':
-                    printf("%s %s\n", program_name, program_version);
+                    printf("%s %s\n", program_name, NETDATA_VERSION);
                     return 0;
                 case 'W':
                     {
@@ -1543,7 +1569,6 @@ int main(int argc, char **argv) {
                             if (unit_test_buffer()) return 1;
                             if (unit_test_str2ld()) return 1;
                             if (buffer_unittest()) return 1;
-                            if (unit_test_bitmaps()) return 1;
 
                             // No call to load the config file on this code-path
                             if (unittest_prepare_rrd(&user)) return 1;
@@ -1591,6 +1616,11 @@ int main(int argc, char **argv) {
                             unittest_running = true;
                             return uuid_unittest();
                         }
+#ifdef OS_WINDOWS
+                        else if(strcmp(optarg, "perflibdump") == 0) {
+                            return windows_perflib_dump(optind + 1 > argc ? NULL : argv[optind]);
+                        }
+#endif
 #ifdef ENABLE_DBENGINE
                         else if(strcmp(optarg, "mctest") == 0) {
                             unittest_running = true;
@@ -1889,7 +1919,7 @@ int main(int argc, char **argv) {
     if (close_open_fds == true) {
         // close all open file descriptors, except the standard ones
         // the caller may have left open files (lxc-attach has this issue)
-        for_each_open_fd(OPEN_FD_ACTION_CLOSE, OPEN_FD_EXCLUDE_STDIN | OPEN_FD_EXCLUDE_STDOUT | OPEN_FD_EXCLUDE_STDERR);
+        os_close_all_non_std_open_fds_except(NULL, 0);
     }
 
     if(!config_loaded) {
@@ -1981,7 +2011,7 @@ int main(int argc, char **argv) {
 
         // initialize the log files
         nd_log_initialize();
-        netdata_log_info("Netdata agent version \""VERSION"\" is starting");
+        netdata_log_info("Netdata agent version '%s' is starting", NETDATA_VERSION);
 
         ieee754_doubles = is_system_ieee754_double();
         if(!ieee754_doubles)
@@ -2111,15 +2141,20 @@ int main(int argc, char **argv) {
 
     delta_startup_time("become daemon");
 
+#if defined(OS_LINUX) || defined(OS_MACOS) || defined(OS_FREEBSD)
     // fork, switch user, create pid file, set process priority
     if(become_daemon(dont_fork, user) == -1)
         fatal("Cannot daemonize myself.");
+#else
+    (void)dont_fork;
+#endif
 
+    netdata_main_spawn_server_init("plugins", argc, (const char **)argv);
     watcher_thread_start();
 
     // init sentry
 #ifdef ENABLE_SENTRY
-        sentry_native_init();
+        nd_sentry_init();
 #endif
 
     // The "HOME" env var points to the root's home dir because Netdata starts as root. Can't use "HOME".
@@ -2143,19 +2178,7 @@ int main(int argc, char **argv) {
     // initialize internal registry
     delta_startup_time("initialize registry");
     registry_init();
-
-    // fork the spawn server
-    delta_startup_time("fork the spawn server");
-    spawn_init();
-
-    /*
-     * Libuv uv_spawn() uses SIGCHLD internally:
-     * https://github.com/libuv/libuv/blob/cc51217a317e96510fbb284721d5e6bc2af31e33/src/unix/process.c#L485
-     * and inadvertently replaces the netdata signal handler which was setup during initialization.
-     * Thusly, we must explicitly restore the signal handler for SIGCHLD.
-     * Warning: extreme care is needed when mixing and matching POSIX and libuv.
-     */
-    signals_restore_SIGCHLD();
+    netdata_random_session_id_generate();
 
     // ------------------------------------------------------------------------
     // initialize rrd, registry, health, rrdpush, etc.
@@ -2166,7 +2189,14 @@ int main(int argc, char **argv) {
     struct rrdhost_system_info *system_info = callocz(1, sizeof(struct rrdhost_system_info));
     __atomic_sub_fetch(&netdata_buffers_statistics.rrdhost_allocations_size, sizeof(struct rrdhost_system_info), __ATOMIC_RELAXED);
     get_system_info(system_info);
-    (void) registry_get_this_machine_guid();
+
+    const char *guid = registry_get_this_machine_guid();
+#ifdef ENABLE_SENTRY
+    nd_sentry_set_user(guid);
+#else
+    UNUSED(guid);
+#endif
+
     system_info->hops = 0;
     get_install_type(&system_info->install_type, &system_info->prebuilt_arch, &system_info->prebuilt_dist);
 
@@ -2197,6 +2227,7 @@ int main(int argc, char **argv) {
 
     if (claiming_pending_arguments)
          claim_agent(claiming_pending_arguments, false, NULL);
+
     load_claiming_state();
 
     // ------------------------------------------------------------------------
@@ -2215,16 +2246,13 @@ int main(int argc, char **argv) {
 
     web_server_config_options();
 
-    netdata_zero_metrics_enabled = config_get_boolean_ondemand(CONFIG_SECTION_DB, "enable zero metrics", CONFIG_BOOLEAN_NO);
-
     set_late_global_environment(system_info);
     for (i = 0; static_threads[i].name != NULL ; i++) {
         struct netdata_static_thread *st = &static_threads[i];
 
         if(st->enabled) {
-            st->thread = mallocz(sizeof(netdata_thread_t));
             netdata_log_debug(D_SYSTEM, "Starting thread %s.", st->name);
-            netdata_thread_create(st->thread, st->name, NETDATA_THREAD_OPTION_DEFAULT, st->start_routine, st);
+            st->thread = nd_thread_create(st->name, NETDATA_THREAD_OPTION_DEFAULT, st->start_routine, st);
         }
         else
             netdata_log_debug(D_SYSTEM, "Not starting thread %s.", st->name);
@@ -2260,10 +2288,9 @@ int main(int argc, char **argv) {
         for (i = 0; static_threads[i].name != NULL; i++) {
             if (!strncmp(static_threads[i].name, "ANALYTICS", 9)) {
                 struct netdata_static_thread *st = &static_threads[i];
-                st->thread = mallocz(sizeof(netdata_thread_t));
                 st->enabled = 1;
                 netdata_log_debug(D_SYSTEM, "Starting thread %s.", st->name);
-                netdata_thread_create(st->thread, st->name, NETDATA_THREAD_OPTION_DEFAULT, st->start_routine, st);
+                st->thread = nd_thread_create(st->name, NETDATA_THREAD_OPTION_DEFAULT, st->start_routine, st);
             }
         }
     }
@@ -2286,22 +2313,21 @@ int main(int argc, char **argv) {
     }
 #endif
 
-    // ------------------------------------------------------------------------
-    // initialize WebRTC
-
     webrtc_initialize();
 
-    // ------------------------------------------------------------------------
-    // unblock signals
-
     signals_unblock();
 
-    // ------------------------------------------------------------------------
-    // Handle signals
+    return 10;
+}
+
+#ifndef OS_WINDOWS
+int main(int argc, char *argv[])
+{
+    int rc = netdata_main(argc, argv);
+    if (rc != 10)
+        return rc;
 
     signals_handle();
-
-    // should never reach this point
-    // but we need it for rpmlint #2752
     return 1;
 }
+#endif
